PagingDataController<T, K extends PagingItem> class abstract

Constructors

PagingDataController(String providerKey)

Properties

hashCode → int
The hash code for this object.
no setterinherited
invisibleItemsThreshold → int
no setter
providerKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFirstDataPageKey() → T?
getInitData(WidgetRef ref) → List<K>?
getProviderKey() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestData(T pageKey) → Future<PagingState<dynamic, PagingItem>>
retryLastFailedRequest(T pageKey) → Future<PagingState<dynamic, PagingItem>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited